import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import '../constants/constant.dart';
import '../screens/data_submit_successfull.dart';
import '../services/api_client.dart';
import '../services/api_urls.dart';

class VisitPdRdProvider with ChangeNotifier {
  final _apiClient = ApiClient();
  bool _isLoading = false;
  void setLoading(bool loading) {
    _isLoading = loading;
    notifyListeners();
  }

  bool get isLoading => _isLoading;

  Future<void> submitVisitPdRd({
    required String pdRdId,
    required String distributorType,
    required String tradeName,
    required String visitDate,
    required String visitTime,
    required String visitPurpose,
    required String meetingSummary,
    String? followUp,
    String? nextVisitDate,
  }) async {
    setLoading(true);
    try {
      Response response = await _apiClient.post(ApiUrls.visitRdPd, data: {
        "addedFor": distributorType,
        "addedForId": pdRdId,
        "tradename": tradeName,
        "visitDate": visitDate,
        "visitTime": visitTime,
        "visitpurpose": visitPurpose,
        "meetingsummary": meetingSummary,
        if (followUp != null) "followup": followUp,
        if (nextVisitDate != null) "nextvisitdate": nextVisitDate
      });
      setLoading(false);
      if (response.statusCode == 201) {
        Navigator.push(
          navigatorKey.currentContext!,
          MaterialPageRoute(
            builder: (context) => const DataSubmitSuccessfull(),
          ),
        );
      }
    } catch (e) {
      setLoading(false);
      String error = "Something went wrong";
      if (e is DioException) {
        error = e.response!.data['message'] ?? "Something went wrong";
      }
      ScaffoldMessenger.of(
        navigatorKey.currentContext!,
      ).showSnackBar(
        SnackBar(
          content: Text(
            error,
          ),
        ),
      );
    }
  }
}
